==> NyaLib-0.13.0-sources.jar: net/danygames2014/nyalib/capability/entity/itemhandler/ItemHandlerMinecartEntityCapability.java <==
package net.danygames2014.nyalib.capability.entity.itemhandler;

import net.minecraft.class_31;
import net.minecraft.class_549;

public class ItemHandlerMinecartEntityCapability extends ItemHandlerEntityCapability {
    class_549 minecart;

    public ItemHandlerMinecartEntityCapability(class_549 minecart) {
        this.minecart = minecart;
    }

    @Override
    public boolean canExtractItem() {
        return true;
    }

    @Override
    public class_31 extractItem(int slot, int amount) {
        return minecart.method_949(slot, amount);
    }

    @Override
    public boolean canInsertItem() {
        return true;
    }

    @Override
    public class_31 insertItem(class_31 stack, int slot) {
        // Check if the current stack is null
        if (minecart.method_954(slot) == null) {
            if (stack.field_751 <= minecart.method_953()) {
                // If the stack fits into the slot, just set it and return null meaning the stack was inserted entirely
                minecart.method_950(slot, stack);
                return null;

            } else if (stack.field_751 > minecart.method_953()) {
                // If the stack is too large for the slot, insert a maximum size stack and then return a remainder stack
                minecart.method_950(slot, stack);

                class_31 remainderStack = stack.method_724();
                remainderStack.field_751 = stack.field_751 - minecart.method_953();
                return remainderStack;
            }
        } else {
            // Check if the existing stack is equal to the one we are trying to insert
            class_31 existingStack = minecart.method_954(slot);
            if (existingStack.method_702(stack)) {
                int freeSpace = minecart.method_953() - existingStack.field_751;

                // Add to the existing stack, the underlying setStack method will make sure to limit the final amount
                existingStack.field_751 += stack.field_751;
                minecart.method_950(slot, existingStack);

                if (freeSpace >= stack.field_751) {
                    // If there is enough space to fit the inserted stack, just add to the stack and return null
                    return null;

                } else {
                    // If there isnt enough space, "fill" the stack up to maximum and return remainder
                    class_31 remainderStack = stack.method_724();
                    remainderStack.field_751 = stack.field_751 - freeSpace;
                    return remainderStack;
                }
            }
        }

        return stack;
    }

    @Override
    public class_31 insertItem(class_31 stack) {
        class_31 insertedStack = stack.method_724();

        for (int i = 0; i < minecart.method_948(); i++) {
            insertedStack = insertItem(insertedStack, i);
            
            // If its null, it was inserted entirely, no need to loop furthers
            if (insertedStack == null) {
                return null;
            }
        }

        return insertedStack;
    }

    @Override
    public class_31 getItemInSlot(int slot) {
        return minecart.method_954(slot);
    }

    @Override
    public int getItemSlots() {
        return minecart.method_948();
    }

    @Override
    public class_31[] getInventory() {
        return minecart.field_2279;
    }
}

==> NyaLib-0.14.0-20250805.181534-1-sources.jar: net/danygames2014/nyalib/capability/entity/itemhandler/ItemHandlerMinecartEntityCapability.java <==
package net.danygames2014.nyalib.capability.entity.itemhandler;

import net.minecraft.class_124;
import net.minecraft.class_31;
import net.minecraft.class_549;

class ItemHandlerMinecartEntityCapability extends ItemHandlerEntityCapability {
    private final class_549 minecart;

    public ItemHandlerMinecartEntityCapability(class_549 minecart) {
        this.minecart = minecart;
    }

    @Override
    public boolean canExtractItem() {
        return true;
    }

    @Override
    public class_31 extractItem(int slot, int amount) {
        return minecart.method_949(slot, amount);
    }

    @Override
    public class_31 extractItem() {
        for (int i = 0; i < getItemSlots(); i++) {
            if (getItemInSlot(i) != null) {
                return extractItem(i, Integer.MAX_VALUE);
            }
        }
        return null;
    }
    
    @Override
    public class_31 extractItem(class_124 item, int amount) {
        class_31 currentStack = null;
        int remaining = amount;

        for (int i = 0; i < getItemSlots(); i++) {
            if (remaining <= 0) {
                break;
            }

            if (currentStack != null) {
                if (this.getItemInSlot(i).method_702(currentStack)) {
                    class_31 extractedStack = extractItem(i, remaining);
                    remaining -= extractedStack.field_751;
                    currentStack.field_751 += extractedStack.field_751;
                }
            } else {
                if (getItemInSlot(i).isOf(item)) {
                    class_31 extractedStack = extractItem(i, remaining);
                    remaining -= extractedStack.field_751;
                    currentStack = extractedStack;
                }
            }
        }

        return currentStack;
    }

    @Override
    public boolean canInsertItem() {
        return true;
    }

    @Override
    public class_31 insertItem(class_31 stack, int slot) {
        // Check if the current stack is null
        if (minecart.method_954(slot) == null) {
            if (stack.field_751 <= minecart.method_953()) {
                // If the stack fits into the slot, just set it and return null meaning the stack was inserted entirely
                minecart.method_950(slot, stack);
                return null;

            } else if (stack.field_751 > minecart.method_953()) {
                // If the stack is too large for the slot, insert a maximum size stack and then return a remainder stack
                minecart.method_950(slot, stack);

                class_31 remainderStack = stack.method_724();
                remainderStack.field_751 = stack.field_751 - minecart.method_953();
                return remainderStack;
            }
        } else {
            // Check if the existing stack is equal to the one we are trying to insert
            class_31 existingStack = minecart.method_954(slot);
            if (existingStack.method_702(stack)) {
                int freeSpace = minecart.method_953() - existingStack.field_751;

                // Add to the existing stack, the underlying setStack method will make sure to limit the final amount
                existingStack.field_751 += stack.field_751;
                minecart.method_950(slot, existingStack);

                if (freeSpace >= stack.field_751) {
                    // If there is enough space to fit the inserted stack, just add to the stack and return null
                    return null;

                } else {
                    // If there isnt enough space, "fill" the stack up to maximum and return remainder
                    class_31 remainderStack = stack.method_724();
                    remainderStack.field_751 = stack.field_751 - freeSpace;
                    return remainderStack;
                }
            }
        }

        return stack;
    }

    @Override
    public class_31 insertItem(class_31 stack) {
        class_31 insertedStack = stack.method_724();

        for (int i = 0; i < minecart.method_948(); i++) {
            insertedStack = insertItem(insertedStack, i);
            
            // If its null, it was inserted entirely, no need to loop furthers
            if (insertedStack == null) {
                return null;
            }
        }

        return insertedStack;
    }

    @Override
    public class_31 getItemInSlot(int slot) {
        return minecart.method_954(slot);
    }

    @Override
    public int getItemSlots() {
        return minecart.method_948();
    }

    @Override
    public class_31[] getInventory() {
        return minecart.field_2279;
    }
}
